yakumo.cinder.v2.qos.Manager

Package yakumo :: Package cinder :: Package v2 :: Module qos :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

manager class for QoS specifications on Block Storage V2 API

Nested Classes | [hide private]
| resource_class resource class for QoS specifications on Block Storage V2 API

Instance Methods | [hide private]
_json2attr(self, kwargs) | source code
yakumo.cinder.v2.qos.Resource |
create(self, name=`'``__UNDEF__``'`, consumer=`'``__UNDEF__``'`, **kwargs) Create a snapshot of a volume | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``volume``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _has_extra_attr = `True`
| _json_resource_key = ``'``qos_specs``'``
| _json_resources_key = ``'``qos_specs``'``
| _url_resource_list_path = ``'``/qos-specs``'``
| _url_resource_path = ``'``/qos-specs``'``
Inherited from `base.Manager` (private): `_has_detail`, `_hidden_methods`, `_id_attr`, `_update_method`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### _json2attr(self, kwargs) | source code
Overrides: base.Manager._json2attr

### create(self, name=`'``__UNDEF__``'`, consumer=`'``__UNDEF__``'`, **kwargs) | source code
Create a snapshot of a volume Parameters: `name` (str) - QoS specification name `consumer` (str) - Consumer of the QoS specification `kwargs` (str=str) - key=value style spec Returns: yakumo.cinder.v2.qos.Resource Created QoS specs Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('consumer'
      , 'consumer', mapper.Noop),]